django_analyses.models.output.definitions package — django_analyses 0.0.3 documentation

# django_analyses.models.output.definitions package

## Submodules

## django_analyses.models.output.definitions.file_output_definition module

class `django_analyses.models.output.definitions.file_output_definition.` `FileOutputDefinition`(id, key, description, outputdefinition_ptr, validate_existence)

  Bases: `django_analyses.models.output.definitions.output_definition.OutputDefinition`

  exception `DoesNotExist`

    Bases: `django_analyses.models.output.definitions.output_definition.OutputDefinition.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.output.definitions.output_definition.OutputDefinition.MultipleObjectsReturned`

  `get_type`() → str
  `output_class`

    alias of `django_analyses.models.output.types.file_output.FileOutput`

  `output_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `outputdefinition_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `outputdefinition_ptr_id`
  `validate_existence`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

## django_analyses.models.output.definitions.float_output_definition module

class `django_analyses.models.output.definitions.float_output_definition.` `FloatOutputDefinition`(id, key, description, outputdefinition_ptr)

  Bases: `django_analyses.models.output.definitions.output_definition.OutputDefinition`

  exception `DoesNotExist`

    Bases: `django_analyses.models.output.definitions.output_definition.OutputDefinition.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.output.definitions.output_definition.OutputDefinition.MultipleObjectsReturned`

  `get_type`() → str
  `output_class`

    alias of `django_analyses.models.output.types.float_output.FloatOutput`

  `output_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `outputdefinition_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `outputdefinition_ptr_id`

## django_analyses.models.output.definitions.output_definition module

class `django_analyses.models.output.definitions.output_definition.` `OutputDefinition`(id, key, description)

  Bases: `django.db.models.base.Model`

  exception `DoesNotExist`

    Bases: `django.core.exceptions.ObjectDoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django.core.exceptions.MultipleObjectsReturned`

  `check_output_class_definition`() → None
  `create_output_instance`(**kwargs) → django_analyses.models.output.output.Output
  `description`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `fileoutputdefinition`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `floatoutputdefinition`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `id`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `key`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `objects` = <django_analyses.models.managers.output_definition.OutputDefinitionManager object>
  `output_class` = None
  `pipe_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `pre_output_instance_create`(kwargs: dict) → None
  `specification_set`

    Accessor to the related objects manager on the forward and reverse sides of a many-to-many relation.

    In the example:

        class Pizza(Model):
            toppings = ManyToManyField(Topping, related_name='pizzas')

    `Pizza.toppings` and `Topping.pizzas` are `ManyToManyDescriptor` instances.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

## django_analyses.models.output.definitions.output_definitions module

class `django_analyses.models.output.definitions.output_definitions.` `OutputDefinitions`

  Bases: `enum.Enum`

  An enumeration.

  `FIL` = 'File'
  `FLT` = 'Float'

## Module contents